@@ -11,16 +11,21 @@ package XML::API::XHTML;
 # ----------------------------------------------------------------------
 use strict;
 use warnings;
-use 5.006;
 use base qw(XML::API);
 
-our $VERSION = $XML::API::VERSION;
+our $VERSION = '0.11';
+
+use constant DOCTYPE => qq{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">};
+
+use constant XSD => {};
+use constant ROOT_ELEMENT => 'html';
+use constant ROOT_ATTRS => {xmlns => 'http://www.w3.org/1999/xhtml'};
+
 
 my $xsd = {};
 
 sub _doctype {
-    return qq{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
-    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">};
+    return q{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">};
 }
 
 sub _xsd {
